@@ -1,6 +1,7 @@
 import subprocess
 
 import typer
+import typer.core
 from typer.testing import CliRunner
 
 from docs_src.arguments.optional import tutorial001 as mod
@@ -14,7 +15,23 @@ app.command()(mod.main)
 def test_call_no_arg():
     result = runner.invoke(app)
     assert result.exit_code != 0
-    assert "Error: Missing argument 'NAME'." in result.output
+    assert "Missing argument 'NAME'." in result.output
+
+
+def test_call_no_arg_standalone():
+    # Mainly for coverage
+    result = runner.invoke(app, standalone_mode=False)
+    assert result.exit_code != 0
+
+
+def test_call_no_arg_no_rich():
+    # Mainly for coverage
+    rich = typer.core.rich
+    typer.core.rich = None
+    result = runner.invoke(app)
+    assert result.exit_code != 0
+    assert "Error: Missing argument 'NAME'" in result.stdout
+    typer.core.rich = rich
 
 
 def test_call_arg():
